@@ -6,24 +6,36 @@ import traceback
 from fastapi import HTTPException
 import requests
 from bs4 import BeautifulSoup
-
+from jaseci.utils.utils import logger
 
 device = torch.device("cuda" if torch.cuda.is_available() else "cpu")
 
-bart_tokenizer = BartTokenizer.from_pretrained("facebook/bart-large-cnn")
-bart_model = BartForConditionalGeneration.from_pretrained("facebook/bart-large-cnn").to(
-    device
-)
+
+@jaseci_action(act_group=["bart_sum"], allow_remote=True)
+def setup(
+    tokenizer: str = "facebook/bart-large-cnn",
+    model: str = "philschmid/bart-large-cnn-samsum",
+):
+    global bart_tokenizer, bart_model
+    try:
+        bart_tokenizer = BartTokenizer.from_pretrained(tokenizer)
+        bart_model = BartForConditionalGeneration.from_pretrained(model).to(device)
+        logger.info(f"{model} - model loaded successfully")
+    except Exception as e:
+        logger.error(
+            f"unable to load model: {model} and tokenize: {tokenizer}\nException: {e}"
+        )
 
 
 @jaseci_action(act_group=["bart_sum"], allow_remote=True)
 def summarize(
     text: Union[List[str], str] = None,  # type: ignore
     url: str = None,  # type: ignore
-    max_length: int = 100,
-    min_length: int = 10,
+    max_length: Union[int, float] = 1.0,
+    min_length: Union[int, float] = 0.1,
     num_beams: int = 4,
 ) -> List[str]:
+    global bart_tokenizer, bart_model
     try:
         if text is not None:
             if isinstance(text, str):
@@ -38,6 +50,12 @@ def summarize(
         inputs = bart_tokenizer.batch_encode_plus(
             text, max_length=1024, return_tensors="pt"
         )
+
+        if not isinstance(max_length, int):
+            max_length = int(inputs["input_ids"].shape[1] * max_length)
+        if not isinstance(min_length, int):
+            min_length = int(inputs["input_ids"].shape[1] * min_length)
+
         summary_ids = bart_model.generate(
             inputs["input_ids"].to(device),
             num_beams=num_beams,
@@ -51,3 +69,9 @@ def summarize(
     except Exception as e:
         traceback.print_exc()
         raise HTTPException(status_code=500, detail=str(e))
+
+
+if __name__ == "__main__":
+    from jaseci.actions.remote_actions import launch_server
+
+    launch_server(port=8000)
