@@ -1,6 +1,8 @@
 from jaseci.utils.test_core import CoreTest, jac_testcase
 from jaseci.actions.live_actions import load_module_actions, unload_module
 import pytest
+import shutil
+from os import path
 
 
 class EntExtTest(CoreTest):
@@ -45,3 +47,6 @@ class EntExtTest(CoreTest):
         super(EntExtTest, cls).tearDownClass()
         ret = unload_module("jac_nlp.ent_ext.ent_ext")
         assert ret is True
+        for temp_path in ["modeloutput", "train"]:
+            if path.exists(temp_path) and path.isdir(temp_path):
+                shutil.rmtree(temp_path)
